name property

String get name
inherited

The name of the file as it was selected by the user in their device.

Use only for cosmetic reasons, do not try to use this as a path.

Implementation

String get name {
  throw UnimplementedError('.name has not been implemented.');
}